'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _inferno = require('inferno');

var _infernoCreateElement = require('inferno-create-element');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _utils = require('./utils');

var _utils2 = require('inferno-animation/dist/utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * These are the open and close animation helpers
 */
function _animateCollapseOnRemove(node, animCls, callback) {
  var clone = node.cloneNode(true);

  var _getDimensions = (0, _utils2.getDimensions)(node),
      width = _getDimensions.width,
      height = _getDimensions.height;

  (0, _utils2.setDimensions)(clone, width, height);
  (0, _utils2.addClassName)(clone, 'collapse show');
  (0, _utils2.setDisplay)(node, 'none !important');
  node.insertAdjacentElement('beforebegin', clone);

  (0, _utils2.addClassName)(clone, 'collapsing');

  (0, _utils2.registerTransitionListener)(clone, function () {
    // *** Cleanup ***
    callback && callback(clone);
    clone.remove();
  });

  setTimeout(function () {
    (0, _utils2.removeClassName)(clone, 'collapse show');
    (0, _utils2.clearDimensions)(clone);
  }, 5);
}

function _animateCollapseOnAdd(node, animCls, callback) {
  var _getDimensions2 = (0, _utils2.getDimensions)(node),
      width = _getDimensions2.width,
      height = _getDimensions2.height;

  (0, _utils2.addClassName)(node, 'collapse');
  (0, _utils2.forceReflow)();

  (0, _utils2.addClassName)(node, 'collapsing');
  (0, _utils2.setDisplay)(node, 'block');

  (0, _utils2.registerTransitionListener)([node, node.children[0]], function () {
    // *** Cleanup ***
    (0, _utils2.removeClassName)(node, 'collapsing');
    (0, _utils2.clearDimensions)(node);
    callback && callback(node);
  });

  //setTimeout(() => {
  (0, _utils2.setDimensions)(node, width, height);
  (0, _utils2.addClassName)(node, 'collapse show');
  (0, _utils2.removeClassName)(node, 'collapse');
  //}, 5) 
}

function Animated(props) {
  var Tag = props.tag,
      children = props.children,
      attrs = _objectWithoutProperties(props, ['tag', 'children']);

  return (0, _infernoCreateElement.createElement)(Tag || 'div', attrs, children);
}

/**
 * This is the bootstrap code:
 */

var defaultProps = {
  isOpen: false,
  tag: 'div',
  onOpened: function onOpened() {},
  onClosed: function onClosed() {}
};

var Collapse = function (_Component) {
  _inherits(Collapse, _Component);

  function Collapse(props) {
    _classCallCheck(this, Collapse);

    var _this = _possibleConstructorReturn(this, (Collapse.__proto__ || Object.getPrototypeOf(Collapse)).call(this, props));

    _this.state = {
      active: false
    };
    return _this;
  }

  _createClass(Collapse, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.setState({
        active: true
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _omit = (0, _utils.omit)(this.props, ['isOpen', 'delay', 'onOpened', 'onClosed']),
          className = _omit.className,
          cssModule = _omit.cssModule,
          Tag = _omit.tag,
          attributes = _objectWithoutProperties(_omit, ['className', 'cssModule', 'tag']);

      var classes = (0, _utils.mapToCssModules)((0, _classnames2.default)(className, !this.state.active && 'InfernoAnimation-noAnim'), cssModule);

      var prefix = this.props.animationClassNames;

      // If hidden
      if (!this.props.isOpen) return null;

      return (0, _inferno.normalizeProps)((0, _inferno.createComponentVNode)(2, Animated, _extends({}, attributes, {
        'tag': Tag,
        'className': classes
      }), null, {
        'onComponentDidMount': function onComponentDidMount(dom) {
          return _animateCollapseOnAdd(dom, _this2.props.onOpened);
        },
        'onComponentWillUnmount': function onComponentWillUnmount(dom) {
          return _animateCollapseOnRemove(dom, _this2.props.onClosed);
        }
      }));
    }
  }]);

  return Collapse;
}(_inferno.Component);

Collapse.defaultProps = defaultProps;

exports.default = Collapse;
module.exports = exports['default'];
//# sourceMappingURL=Collapse.js.map